@@ -3,5 +3,5 @@
  ##  library.dynam("Rwave", pkg, lib)
   library.dynam("GEOmap", pkg, lib)
   
-  cat("GEOmap is loaded\n")
+ ##  cat("GEOmap is loaded\n")
 }
